// filename ******** Main.C ************** 
// LCD Display (HD44780) on PortH, PORTJ for the MC68HC812A4   
// Jonathan W. Valvano 1/30/04
// Purpose: test program for LCD.C driver

/*   
  size is 1*16
  ground = pin 1    Vss
  power  = pin 2    Vdd   +5v
  ground = pin 3    Vlc   could be tied to 10Kpot
  PJ2    = pin 4    RS    (1 for data, 0 for control/status)
  PJ1    = pin 5    R/W   (1 for read, 0 for write)
  PJ0    = pin 6    E     (enable)
  PH0-7  = pins7-14 DB0-7 (8 bit data)
*/

#include <hidef.h>         /* common defines and macros */
#include <mc68hc812a4.h>   /* derivative information */
#include "LCD.H"

#pragma LINK_INFO DERIVATIVE "hc12a4"

//--------------------TimerInit---------------
// initialize timer module to 1us TCNT clock
// inputs: none
// outputs: none
void TimerInit(void){
  COPCTL = 0x00;    // disable COP 
  DDRT |= 0x40;     // PortT bit 6 is output to LED
  TSCR |= 0x80;     // TEN(enable)
  TMSK2 = 0x23;     // to specify 1us clock
// Be careful, TMSK2 and TSCR maybe set in other rituals
}

//---------------------mwait---------------------
// wait specified number of msec
// Input: number of msec to wait
// Output: none
// assumes TCNT timer is running at 667ns
void mwait(unsigned short msec){ short TimeLeft,EndT;
  for(; msec>0; msec--){
    EndT = TCNT+1000;    // wait 1 ms
    do{
      TimeLeft = (short)TCNT-EndT;
    }
    while((TimeLeft<0)||(TimeLeft>100));   // wait 
  }
}

//---------------------check---------------------
// if LCD broken toggle LED1 at 2Hz
// Input: last LCD status, 0 means bad
// Output: none
// Error: if status is zero, this function will not return
void check(short status){	 // 0 if LCD is broken
  if(status ==0){		   
    for(;;) {
      PORTT ^= 0x40;   // fast toggle LED
      mwait(250);      // 0.25 sec wait
    }
  }
}

//---------------------blank---------------------
// move cursor to second half of LCD display
// Input: none
// Output: none
void blank(void){
  check(LCD_OutString("                                "));
}
//---------------------swait---------------------
// wait specified 2 sec, then clear LCD
// Input: none
// Output: none
// uses mswait and TCNT timer
void swait(void){			
  mwait(2000);     // 2 sec wait
  PORTT ^= 0x40;   // toggle LED
  check(LCD_Clear());
}
void main(void) {
  TimerInit();      // disable COP, enable Port T 
  check(LCD_Open(LCDINC+LCDNOSHIFT,
    LCDNOCURSOR+LCDNOBLINK,
    LCDNOSCROLL+LCDLEFT,
    LCD2LINE+LCD7DOT));
  check(LCD_OutString("Adapt812")); blank();
  check(LCD_OutString(" LCD    ")); swait();
  for(;;) {
    check(LCD_OutString("ABCDEFGH")); blank();
    check(LCD_OutString("IJKLMNOP")); swait();
    check(LCD_OutString("01234567")); blank();
    check(LCD_OutString("890,./<>")); swait();
    check(LCD_OutString("abcdefgh")); blank();
    check(LCD_OutString("ijklmnop")); swait();
    check(LCD_OutString("!@#$%^&*")); blank();
    check(LCD_OutString("()_+-=[]")); swait();
  } 
}
